<?php
/**
 * The Header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="main">
 *
 * @package Something-Fishy
 * @since Something Fishy1.0
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>" />
<meta name="viewport" content="width=device-width" />
<title><?php
	/*
	 * Print the <title> tag based on what is being viewed.
	 */
	global $page, $paged;

	wp_title( '|', true, 'right' );

	// Add the blog name.
	bloginfo( 'name' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		echo " | $site_description";

	// Add a page number if necessary:
	if ( $paged >= 2 || $page >= 2 )
		echo ' | ' . sprintf( __( 'Page %s', 'something-fishy' ), max( $paged, $page ) );

	?></title>
<link rel="profile" href="http://gmpg.org/xfn/11" />
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />
<!--[if lt IE 9]>
<script src="<?php echo get_template_directory_uri(); ?>/js/html5.js" type="text/javascript"></script>
<![endif]-->

<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="hfeed site">
	<?php do_action( 'somethingfishy_before' ); ?>

	<div class="sea-sprite" id="worm">
		<div id="worm-bubble">
			<?php _e( 'Get me outta here!', 'something-fishy' ); ?>
		</div>
	</div>

	<div class="parallax" id="bubbles-1"></div>
	<div class="parallax" id="bubbles-2"></div>
	<div class="parallax" id="fish"></div>
	<div class="parallax" id="fish-2"></div>

	<div class="parallax" id="whale"></div>
	<div class="parallax" id="crab"></div>
	<div class="parallax" id="dolphin"></div>
	<div class="parallax" id="jellyfish"></div>
	<div class="parallax" id="turtle"></div>
	<div class="parallax" id="orangefish"></div>
	<div class="parallax" id="orangefish-2"></div>

	<header id="masthead" class="site-header" role="banner">
		<?php $header_image = get_header_image();
		if ( ! empty( $header_image ) ) { ?>
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home">
				<img src="<?php header_image(); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="" />
			</a>
		<?php } // if ( ! empty( $header_image ) ) ?>
		<hgroup>
			<h1 class="site-title"><a href="<?php echo home_url( '/' ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
		</hgroup>
		<nav role="navigation" class="site-navigation main-navigation">
			<h2 class="site-description"><?php bloginfo( 'description' ); ?></h2>
			<h1 class="assistive-text"><?php _e( 'Menu', 'something-fishy' ); ?></h1>
			<div class="assistive-text skip-link"><a href="#content" title="<?php esc_attr_e( 'Skip to content', 'something-fishy' ); ?>"><?php _e( 'Skip to content', 'something-fishy' ); ?></a></div>
			<?php wp_nav_menu( array( 'theme_location' => 'primary' ) ); ?>
		</nav>
	</header><!-- #masthead .site-header -->

	<div id="main">